/*****************************************************************************

	unsort - reorder files semi-randomly
	Copyright (C) 2007, 2008  Wessel Dankers <wsl@fruit.je>

	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.

*****************************************************************************/

#ifndef IOVEC_H
#define IOVEC_H

#include <stdint.h>
#include <sys/uio.h>

#include "filebuf.h"

extern uint32_t iovec_parse(filebuf_t *, unsigned char sep, struct iovec *);
extern void iovec_shuffle(struct iovec *, uint32_t *, uint32_t);
extern void iovec_write(int fd, struct iovec *, uint32_t);

#endif
